Crate numaflow

source ·
A Rust SDK for Numaflow. The Rust SDK is experimental has only implemented the most important features. It will support all the core features eventually. It supports Map, Reduce, and User Defined Sinks.

Please note that the Rust SDK is experimental and will be refactored in the future to make it more idiomatic.

Modules