Crate rusterix

Crate rusterix 

Rusterix is a fast software renderer for 2D and 3D triangles and lines. Its goals are to provide an easy and portable alternative to hardware rasterization for retro and low-poly games.

Re-exports

pub use crate::batch::Batch;
pub use crate::batch::CullMode;
pub use crate::batch::PrimitiveMode;
pub use crate::camera::d3firstp::D3FirstPCamera;
pub use crate::camera::d3iso::D3IsoCamera;
pub use crate::camera::d3orbit::D3OrbitCamera;
pub use crate::camera::D3Camera;
pub use crate::edge::Edges;
pub use crate::entity::Entity;
pub use crate::intodata::IntoDataInput;
pub use crate::map::light::Light;
pub use crate::map::linedef::Linedef;
pub use crate::map::meta::MapMeta;
pub use crate::map::sector::Sector;
pub use crate::map::tile::Tile;
pub use crate::map::vertex::Vertex;
pub use crate::map::Map;
pub use crate::map::MapToolType;
pub use crate::rasterizer::Rasterizer;
pub use crate::rect::Rect;
pub use crate::scene::Scene;
pub use crate::scenebuilder::d2preview::D2PreviewBuilder;
pub use crate::scenebuilder::SceneBuilder;
pub use crate::script::mapscript::MapScript;
pub use crate::shader::grid::GridShader;
pub use crate::shader::vgradient::VGrayGradientShader;
pub use crate::shader::Shader;
pub use crate::texture::RepeatMode;
pub use crate::texture::SampleMode;
pub use crate::texture::Texture;

Modules

batch
camera
edge
entities
entity
intodata
map
prelude
rasterizer
rect
scene
scenebuilder
script
shader
texture
wavefront

Structs

Embedded

Constants

BLACK
TRANSPARENT
WHITE

Functions

pixel_to_vec4
Convert from Pixel to Vec4
vec4_to_pixel
Convert from Vec4 to Pixel

Type Aliases

Pixel