Re-exports
pub use map::PrefixTreeMap;pub use map::Entry;pub use map::VacantEntry;pub use map::OccupiedEntry;pub use set::PrefixTreeSet;
Modules
- A map from byte strings to arbitrary values, based on a prefix tree.
- A set of byte strings, based on a prefix tree.